==> eiffelstudio-18.11.10.2592.tar: F_code/C4/ew194.c <==
/*
 * Code for class EW_TEST_ENVIRONMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew194.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_TEST_ENVIRONMENT}.make */
void F631_3561 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 630, Current, 0, 1, 5912);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {650,879,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F647_3694(RTCW(tr1), arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {633,884,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F634_3609(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = F202_2514(Current);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.define */
void F631_3562 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("define", 630, Current, 0, 2, 5913);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F647_3741(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove */
void F631_3563 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove", 630, Current, 0, 1, 5914);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F647_3746(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.add_environment_variable */
void F631_3564 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("add_environment_variable", 630, Current, 0, 2, 5915);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F647_3741(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove_environment_variable */
void F631_3565 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove_environment_variable", 630, Current, 0, 1, 5902);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F647_3746(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.set_max_c_processes */
void F631_3566 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_max_c_processes", 630, Current, 0, 1, 5903);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) arg1;
	RTHOOK(3);
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.substitute */
EIF_REFERENCE F631_3568 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_32 loc4 = (EIF_CHARACTER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN loc8 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,tr1);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLR(4,loc5);
	RTLR(5,loc6);
	RTLIU(6);
	
	RTEAA("substitute", 630, Current, 8, 1, 5905);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(881, 0x00).id, 881, _OBJSIZ_1_1_0_3_0_0_0_0_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4302[Dtype(arg1)-879]);
	F880_5600(RTCW(tr1), ti4_1);
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4302[Dtype(arg1)-879]);
	RTHOOK(3);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(4);
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		RTHOOK(5);
		loc4 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4149[Dtype(arg1)-880])(RTCW(arg1), loc1);
		RTHOOK(6);
		if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 36U)) {
			RTHOOK(7);
			if (loc7) {
				RTHOOK(8);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				RTHOOK(9);
				F882_5728(RTCW(Result), loc4);
			} else {
				RTHOOK(10);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		} else {
			RTHOOK(11);
			if (loc7) {
				RTHOOK(12);
				if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 40U)) {
					RTHOOK(13);
					loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				} else {
					RTHOOK(14);
					loc3 = (EIF_INTEGER_32) loc1;
					for (;;) {
						RTHOOK(15);
						tb1 = '\01';
						if (!(EIF_BOOLEAN) (loc1 > loc2)) {
							tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4149[Dtype(arg1)-880])(RTCW(arg1), loc1);
							tb1 = (EIF_BOOLEAN) !F37_575(Current, tw1);
						}
						if (tb1) break;
						RTHOOK(16);
						loc1++;
					}
					RTHOOK(17);
					loc1--;
					RTHOOK(18);
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4226[Dtype(arg1)-880])(RTCW(arg1), loc3, loc1);
					RTHOOK(19);
					loc6 = F631_3569(Current, loc5);
					RTHOOK(20);
					if ((EIF_BOOLEAN)(loc6 != NULL)) {
						RTHOOK(21);
						F882_5713(RTCW(Result), loc6);
					} else {
						RTHOOK(22);
						F882_5728(RTCW(Result), (EIF_CHARACTER_32) 36U);
						RTHOOK(23);
						F882_5713(RTCW(Result), loc5);
					}
					RTHOOK(24);
					if (loc8) {
						RTHOOK(25);
						loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
						RTHOOK(26);
						loc1++;
					}
					RTHOOK(27);
					loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				}
			} else {
				RTHOOK(28);
				F882_5728(RTCW(Result), loc4);
			}
		}
		RTHOOK(29);
		loc1++;
	}
	RTHOOK(30);
	if (loc7) {
		RTHOOK(31);
		F882_5728(RTCW(Result), loc4);
	}
	RTHOOK(32);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.value */
EIF_REFERENCE F631_3569 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("value", 630, Current, 0, 1, 5906);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F647_3699(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.replaced_variable */
EIF_REFERENCE F631_3570 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("replaced_variable", 630, Current, 0, 1, 5907);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4302[Dtype(arg1)-879]);
	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4149[Dtype(arg1)-880])(RTCW(arg1), ((EIF_INTEGER_32) 1L));
		tb1 = (EIF_BOOLEAN)(tw1 == (EIF_CHARACTER_32) 36U);
	}
	if (tb1) {
		RTHOOK(2);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4302[Dtype(arg1)-879]);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4226[Dtype(arg1)-880])(RTCW(arg1), ((EIF_INTEGER_32) 2L), ti4_1);
		tr1 = F631_3569(Current, tr1);
		Result = F877_5529(RTCW(tr1));
	}
	RTHOOK(3);
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
		RTHOOK(4);
		Result = F877_5529(RTCW(arg1));
		RTHOOK(5);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) Result;
	}
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.environment_variables */
EIF_REFERENCE F631_3572 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {EW_TEST_ENVIRONMENT}.table */
EIF_REFERENCE F631_3573 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {EW_TEST_ENVIRONMENT}.list */
EIF_REFERENCE F631_3574 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


void EIF_Minit194 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/ew194.c <==
/*
 * Code for class EW_TEST_ENVIRONMENT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew194.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_TEST_ENVIRONMENT}.make */
void F631_3568 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 630, Current, 0, 1, 5909);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {650,879,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F647_3701(RTCW(tr1), arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {633,884,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F634_3616(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = F202_2515(Current);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.define */
void F631_3569 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("define", 630, Current, 0, 2, 5910);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F647_3748(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove */
void F631_3570 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove", 630, Current, 0, 1, 5911);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F647_3753(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.add_environment_variable */
void F631_3571 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("add_environment_variable", 630, Current, 0, 2, 5912);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F647_3748(RTCW(tr1), arg2, arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.remove_environment_variable */
void F631_3572 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("remove_environment_variable", 630, Current, 0, 1, 5913);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	F647_3753(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.set_max_c_processes */
void F631_3573 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_max_c_processes", 630, Current, 0, 1, 5914);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_3_0_0_1_) = (EIF_INTEGER_32) arg1;
	RTHOOK(3);
	RTEE;
}

/* {EW_TEST_ENVIRONMENT}.substitute */
EIF_REFERENCE F631_3575 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_32 loc4 = (EIF_CHARACTER_32) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN loc8 = (EIF_BOOLEAN) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLR(3,loc5);
	RTLR(4,loc6);
	RTLIU(5);
	
	RTEAA("substitute", 630, Current, 8, 1, 5916);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(881, 0x00).id, 881, _OBJSIZ_1_1_0_3_0_0_0_0_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4323[Dtype(arg1)-879]);
	F880_5621(RTCW(Result), ti4_1);
	RTHOOK(2);
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4323[Dtype(arg1)-879]);
	RTHOOK(3);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(4);
		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
		RTHOOK(5);
		loc4 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4170[Dtype(RTCW(arg1))-880])(arg1, loc1);
		RTHOOK(6);
		if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 36U)) {
			RTHOOK(7);
			if (loc7) {
				RTHOOK(8);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				RTHOOK(9);
				F882_5749(RTCW(Result), loc4);
			} else {
				RTHOOK(10);
				loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			}
		} else {
			RTHOOK(11);
			if (loc7) {
				RTHOOK(12);
				if ((EIF_BOOLEAN)(loc4 == (EIF_CHARACTER_32) 40U)) {
					RTHOOK(13);
					loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				} else {
					RTHOOK(14);
					loc3 = (EIF_INTEGER_32) loc1;
					for (;;) {
						RTHOOK(15);
						tb1 = '\01';
						if (!(EIF_BOOLEAN) (loc1 > loc2)) {
							tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4170[Dtype(RTCW(arg1))-880])(arg1, loc1);
							tb1 = (EIF_BOOLEAN) !F37_575(Current, tw1);
						}
						if (tb1) break;
						RTHOOK(16);
						loc1++;
					}
					RTHOOK(17);
					loc1--;
					RTHOOK(18);
					loc5 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4247[Dtype(RTCW(arg1))-880])(arg1, loc3, loc1);
					RTHOOK(19);
					loc6 = F631_3576(Current, loc5);
					RTHOOK(20);
					if ((EIF_BOOLEAN)(loc6 != NULL)) {
						RTHOOK(21);
						F882_5734(RTCW(Result), loc6);
					} else {
						RTHOOK(22);
						F882_5749(RTCW(Result), (EIF_CHARACTER_32) 36U);
						RTHOOK(23);
						F882_5734(RTCW(Result), loc5);
					}
					RTHOOK(24);
					if (loc8) {
						RTHOOK(25);
						loc8 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
						RTHOOK(26);
						loc1++;
					}
					RTHOOK(27);
					loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
				}
			} else {
				RTHOOK(28);
				F882_5749(RTCW(Result), loc4);
			}
		}
		RTHOOK(29);
		loc1++;
	}
	RTHOOK(30);
	if (loc7) {
		RTHOOK(31);
		F882_5749(RTCW(Result), loc4);
	}
	RTHOOK(32);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.value */
EIF_REFERENCE F631_3576 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("value", 630, Current, 0, 1, 5917);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	Result = F647_3706(RTCW(tr1), arg1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_TEST_ENVIRONMENT}.replaced_variable */
EIF_REFERENCE F631_3577 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,Result);
	RTLIU(4);
	
	RTEAA("replaced_variable", 630, Current, 0, 1, 5918);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4323[Dtype(arg1)-879]);
	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 1L))) {
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4170[Dtype(RTCW(arg1))-880])(arg1, ((EIF_INTEGER_32) 1L));
		tb1 = (EIF_BOOLEAN)(tw1 == (EIF_CHARACTER_32) 36U);
	}
	if (tb1) {
		RTHOOK(2);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O4323[Dtype(arg1)-879]);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32)) R4247[Dtype(RTCW(arg1))-880])(arg1, ((EIF_INTEGER_32) 2L), ti4_1);
		tr1 = F631_3576(Current, tr1);
		Result = F877_5550(RTCW(tr1));
	}
	RTHOOK(3);
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
		RTHOOK(4);
		Result = F877_5550(RTCW(arg1));
		RTHOOK(5);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) Result;
	}
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit194 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
